fn generate_file_path(
field: &Field,
store_kind: StoreKind,
) -> Result<PathBuf, ControllerError>Expand description
Generates a path for a generic file with the appropriate extension based on its filename.
fn generate_file_path(
field: &Field,
store_kind: StoreKind,
) -> Result<PathBuf, ControllerError>Generates a path for a generic file with the appropriate extension based on its filename.