fn generate_image_path(
field: &Field,
store_kind: StoreKind,
) -> Result<PathBuf, ControllerError>Expand description
Generates a path for an image file with the appropriate extension.
fn generate_image_path(
field: &Field,
store_kind: StoreKind,
) -> Result<PathBuf, ControllerError>Generates a path for an image file with the appropriate extension.